__title__ = "Information plugin"
__description__ = "A dialog to compute different metrics on the database of variants"
__long_description__ = ""
__author__ = "Sacha schutz"
__version__ = "1.0.0"
